HTML — Translate Toolkit 2.4.0 documentation

# HTML

The Translate Toolkit is able to process HTML files using the html2po converter.

The HTML support is basic, so please be aware of that.

## Conformance

- Can identify almost all tags and attributes that are localisable.
- Does not convert HTML entities (e.g. `&copy;`) to normal strings
- It does not handle inline elements well and will drop them, so complicated HTML might not make it through the filter

## References

- Using character entities: http://www.w3.org/International/questions/qa-escapes